produce combinations of nominal variables
.expandValues(attributes, data, all)a list of attributes to be recoded. Vectors (as elements of the list) are possible to specify combinations of attributes to be recoded as a single complex attribute.
a data frame with nominal data, attributes as columns, observations as rows.
Logical: should all values be produced or only those with existing data?
expandValues is an internal help function to show the various value-combinations when combining attributes.
Just a helper.